@@ -6,10 +6,11 @@ import torch.nn.functional as F
 import math
 from torch.autograd import Variable
 import torch.utils.model_zoo as model_zoo
-from UNet.model import *
-from UNet.train import train
+# from UNet.model import *
+from UNet_zoo.model import *
+from UNet_zoo.train import *
 from UNetPP import *
-from PointNet.model import *
+from PointNet import *
 from StackGAN import *
 from CharCNN import *
 from PSPNet import *
@@ -37,7 +38,7 @@ class UNet:
         return model
     
     def train(model, train_dataloader, optimizer, loss, device):
-        UNet.train.train(model, train_dataloader, optimizer, loss, device)
+        train_UNet(model, train_dataloader, optimizer, loss, device)
 
 # def UNet(num_channels = 1, pretrained = False):        # num_channels = 1 if grayscale image else num_channels = 3 if color image
 #     if pretrained == True:
